@@ -1,71 +1,45 @@
 /*
  *  Project   : tin - a Usenet reader
  *  Module    : strftime.c
- *  Author    : A. Robbins & I. Lea
- *  Created   : 1991-02-01
- *  Updated   : 1993-08-15
+ *  Author    : A.Robbins & I.Lea
+ *  Created   : 01-02-91
+ *  Updated   : 15-08-93
  *  Notes     : Relatively quick-and-dirty implemenation of ANSI library
  *              routine for System V Unix systems.
+ *              It's written in old-style C for maximal portability.
  *              If target system already has strftime() call the #define
  *              HAVE_STRFTIME can be set to use it.
- *  Example   : time(&secs);
- *              tm = localtime(&secs);
- *              num = strftime(buf, sizeof(buf), "%a %d-%m-%y %H:%M:%S", tm);
- *
- * Copyright (c) 1991-2009 Arnold Robbins <arnold@skeeve.com>
- * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior written
- *    permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
- * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
- * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
- * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *  Example   : time (&secs);
+ *              tm = localtime (&secs);
+ *              num = strftime (buf, sizeof (buf), "%a %d-%m-%y %H:%M:%S", tm);
+ *  Copyright : (c) Copyright 1991-94 by Arnold Robbins & Iain Lea
+ *              You may  freely  copy or  redistribute  this software,
+ *              so  long as there is no profit made from its use, sale
+ *              trade or  reproduction.  You may not change this copy-
+ *              right notice, and it must be included in any copy made
  */
 
-
-#ifndef TIN_H
-#	include "tin.h"
-#endif /* !TIN_H */
+#include "tin.h"
 
 #ifdef SYSV
 extern int daylight;
-#endif /* SYSV */
+#endif
 
-#ifndef HAVE_STRFTIME
-#	define SYSV_EXT	1	/* stuff in System V ascftime routine */
-#endif /* !HAVE_STRFTIME */
+#define SYSV_EXT	1	/* stuff in System V ascftime routine */
 
 /*
  * strftime --- produce formatted time
  */
 
 size_t
-my_strftime(
+my_strftime (
 	char *s,
 	size_t maxsize,
 	const char *format,
 	struct tm *timeptr)
 {
 #ifdef HAVE_STRFTIME
-	return strftime(s, maxsize, format, timeptr);
+	return strftime (s, maxsize, format, timeptr);
 #else
 	char *endp = s + maxsize;
 	char *start = s;
@@ -75,24 +49,24 @@ my_strftime(
 	/*
 	 * various tables, useful in North America
 	 */
-	static const char *days_a[] = {
+	static char *days_a[] = {
 		"Sun", "Mon", "Tue", "Wed",
 		"Thu", "Fri", "Sat",
 	};
-	static const char *days_l[] = {
+	static char *days_l[] = {
 		"Sunday", "Monday", "Tuesday", "Wednesday",
 		"Thursday", "Friday", "Saturday",
 	};
-	static const char *months_a[] = {
+	static char *months_a[] = {
 		"Jan", "Feb", "Mar", "Apr", "May", "Jun",
 		"Jul", "Aug", "Sep", "Oct", "Nov", "Dec",
 	};
-	static const char *months_l[] = {
+	static char *months_l[] = {
 		"January", "February", "March", "April",
 		"May", "June", "July", "August", "September",
 		"October", "November", "December",
 	};
-	static const char *ampm[] = { "AM", "PM", };
+	static char *ampm[] = { "AM", "PM", };
 
 	if (s == NULL || format == NULL || timeptr == NULL || maxsize == 0)
 		return 0;
@@ -101,12 +75,12 @@ my_strftime(
 		return 0;
 
 #ifdef HAVE_TZSET
-	tzset();
-#else
-#	ifdef HAVE_SETTZ
-	settz();
-#	endif /* HAVE_SETTZ */
-#endif /* HAVE_TZSET */
+	tzset ();
+#endif
+
+#ifdef HAVE_SETTZ
+	settz ();
+#endif
 
 	for (; *format && s < endp - 1; format++) {
 		tbuf[0] = '\0';
@@ -131,9 +105,9 @@ my_strftime(
 			strcpy(tbuf, days_l[timeptr->tm_wday]);
 			break;
 
-#	ifdef SYSV_EXT
+#ifdef SYSV_EXT
 		case 'h':	/* abbreviated month name */
-#	endif /* SYSV_EXT */
+#endif
 		case 'b':	/* abbreviated month name */
 			strcpy(tbuf, months_a[timeptr->tm_mon]);
 			break;
@@ -143,7 +117,7 @@ my_strftime(
 			break;
 
 		case 'c':	/* appropriate date and time representation */
-			snprintf(tbuf, sizeof(tbuf), "%s %s %2d %02d:%02d:%02d %d",
+			sprintf(tbuf, "%s %s %2d %02d:%02d:%02d %d",
 				days_a[timeptr->tm_wday],
 				months_a[timeptr->tm_mon],
 				timeptr->tm_mday,
@@ -154,11 +128,11 @@ my_strftime(
 			break;
 
 		case 'd':	/* day of the month, 01 - 31 */
-			snprintf(tbuf, sizeof(tbuf), "%02d", timeptr->tm_mday);
+			sprintf(tbuf, "%02d", timeptr->tm_mday);
 			break;
 
 		case 'H':	/* hour, 24-hour clock, 00 - 23 */
-			snprintf(tbuf, sizeof(tbuf), "%02d", timeptr->tm_hour);
+			sprintf(tbuf, "%02d", timeptr->tm_hour);
 			break;
 
 		case 'I':	/* hour, 12-hour clock, 01 - 12 */
@@ -167,35 +141,38 @@ my_strftime(
 				i = 12;
 			else if (i > 12)
 				i -= 12;
-			snprintf(tbuf, sizeof(tbuf), "%02d", i);
+			sprintf(tbuf, "%02d", i);
 			break;
 
 		case 'j':	/* day of the year, 001 - 366 */
-			snprintf(tbuf, sizeof(tbuf), "%03d", timeptr->tm_yday + 1);
+			sprintf(tbuf, "%03d", timeptr->tm_yday + 1);
 			break;
 
 		case 'm':	/* month, 01 - 12 */
-			snprintf(tbuf, sizeof(tbuf), "%02d", timeptr->tm_mon + 1);
+			sprintf(tbuf, "%02d", timeptr->tm_mon + 1);
 			break;
 
 		case 'M':	/* minute, 00 - 59 */
-			snprintf(tbuf, sizeof(tbuf), "%02d", timeptr->tm_min);
+			sprintf(tbuf, "%02d", timeptr->tm_min);
 			break;
 
 		case 'p':	/* am or pm based on 12-hour clock */
-			strcpy(tbuf, ampm[((timeptr->tm_hour < 12) ? 0 : 1)]);
+			if (timeptr->tm_hour < 12)
+				strcpy(tbuf, ampm[0]);
+			else
+				strcpy(tbuf, ampm[1]);
 			break;
 
 		case 'S':	/* second, 00 - 61 */
-			snprintf(tbuf, sizeof(tbuf), "%02d", timeptr->tm_sec);
+			sprintf(tbuf, "%02d", timeptr->tm_sec);
 			break;
 
 		case 'w':	/* weekday, Sunday == 0, 0 - 6 */
-			snprintf(tbuf, sizeof(tbuf), "%d", timeptr->tm_wday);
+			sprintf(tbuf, "%d", timeptr->tm_wday);
 			break;
 
 		case 'x':	/* appropriate date representation */
-			snprintf(tbuf, sizeof(tbuf), "%s %s %2d %d",
+			sprintf(tbuf, "%s %s %2d %d",
 				days_a[timeptr->tm_wday],
 				months_a[timeptr->tm_mon],
 				timeptr->tm_mday,
@@ -203,7 +180,7 @@ my_strftime(
 			break;
 
 		case 'X':	/* appropriate time representation */
-			snprintf(tbuf, sizeof(tbuf), "%02d:%02d:%02d",
+			sprintf(tbuf, "%02d:%02d:%02d",
 				timeptr->tm_hour,
 				timeptr->tm_min,
 				timeptr->tm_sec);
@@ -211,14 +188,14 @@ my_strftime(
 
 		case 'y':	/* year without a century, 00 - 99 */
 			i = timeptr->tm_year % 100;
-			snprintf(tbuf, sizeof(tbuf), "%d", i);
+			sprintf(tbuf, "%d", i);
 			break;
 
 		case 'Y':	/* year with century */
-			snprintf(tbuf, sizeof(tbuf), "%d", timeptr->tm_year + 1900);
+			sprintf(tbuf, "%d", 1900 + timeptr->tm_year);
 			break;
 
-#	ifdef SYSV_EXT
+#ifdef SYSV_EXT
 		case 'n':	/* same as \n */
 			tbuf[0] = '\n';
 			tbuf[1] = '\0';
@@ -230,25 +207,25 @@ my_strftime(
 			break;
 
 		case 'D':	/* date as %m/%d/%y */
-			my_strftime(tbuf, sizeof(tbuf), "%m/%d/%y", timeptr);
+			my_strftime(tbuf, sizeof tbuf, "%m/%d/%y", timeptr);
 			break;
 
 		case 'e':	/* day of month, blank padded */
-			snprintf(tbuf, sizeof(tbuf), "%2d", timeptr->tm_mday);
+			sprintf(tbuf, "%2d", timeptr->tm_mday);
 			break;
 
 		case 'r':	/* time as %I:%M:%S %p */
-			my_strftime(tbuf, sizeof(tbuf), "%I:%M:%S %p", timeptr);
+			my_strftime(tbuf, sizeof tbuf, "%I:%M:%S %p", timeptr);
 			break;
 
 		case 'R':	/* time as %H:%M */
-			my_strftime(tbuf, sizeof(tbuf), "%H:%M", timeptr);
+			my_strftime(tbuf, sizeof tbuf, "%H:%M", timeptr);
 			break;
 
 		case 'T':	/* time as %H:%M:%S */
-			my_strftime(tbuf, sizeof(tbuf), "%H:%M:%S", timeptr);
+			my_strftime(tbuf, sizeof tbuf, "%H:%M:%S", timeptr);
 			break;
-#	endif /* SYSV_EXT */
+#endif
 
 		default:
 			tbuf[0] = '%';
@@ -256,13 +233,13 @@ my_strftime(
 			tbuf[2] = '\0';
 			break;
 		}
-		if ((i = strlen(tbuf))) {
+		i = strlen(tbuf);
+		if (i)
 			if (s + i < endp - 1) {
 				strcpy(s, tbuf);
 				s += i;
 			} else
 				return 0;
-		}
 	}
 out:
 	if (s < endp && *format == '\0') {
@@ -271,5 +248,5 @@ out:
 	} else
 		return 0;
 
-#endif /* HAVE_STRFTIME */
+#endif	/* HAVE_STRFTIME */
 }
