@@ -36,9 +36,7 @@
 **  on.
 */
 
-#ifndef TIN_H
-#	include "tin.h"
-#endif /* !TIN_H */
+#include "tin.h"
 
 #define ABORT	-1
 
@@ -51,20 +49,17 @@
 /* Do tar(1) matching rules, which ignore a trailing slash? */
 #undef MATCH_TAR_PATTERN
 
-/*
- * local prototypes
- */
-static int DoMatch(register const char *text, register char *p);
 
 /*
- *  Match text and p, return 1 (TRUE), 0 (FALSE), or -1 (ABORT).
+ *  Match text and p, return TRUE, FALSE, or ABORT.
  */
 
 static int
-DoMatch (
+DoMatch(
 	register const char *text,
 	register char *p)
 {
+#ifndef INDEX_DAEMON
 	register int last;
 	register int matched;
 	register int reverse;
@@ -79,7 +74,7 @@ DoMatch (
 				/* FALLTHROUGH */
 			default:
 				if (*text != *p)
-					return 0;
+					return FALSE;
 				continue;
 			case '?':
 				/* Match anything. */
@@ -90,9 +85,9 @@ DoMatch (
 					continue;
 				if (*p == '\0')
 					/* Trailing star matches everything. */
-					return 1;
+					return TRUE;
 				while (*text)
-					if ((matched = DoMatch(text++, p)) != 0)
+					if ((matched = DoMatch(text++, p)) != FALSE)
 						return matched;
 				return ABORT;
 			case '[':
@@ -109,14 +104,15 @@ DoMatch (
 					if (*p == '-' && p[1] != ']' ? *text <= *++p && *text >= last : *text == *p)
 						matched = TRUE;
 				if (matched == reverse)
-					return 0;
+					return FALSE;
 				continue;
 			}
 		}
 #ifdef MATCH_TAR_PATTERN
 		if (*text == '/')
-			return 1;
+			return TRUE;
 #endif /* MATCH_TAR_ATTERN */
+#endif /* INDEX_DAEMON */
 	return *text == '\0';
 }
 
@@ -125,36 +121,19 @@ DoMatch (
  *  User-level routine.  Returns TRUE or FALSE.
  */
 
-t_bool
-wildmat (
+int
+wildmat(
 	const char *text,
-	char *p,
-	t_bool icase)
+	char *p)
 {
-	t_bool ret;
-	char * txt;
-
 	/*
 	 * Make sure the pattern is not NULL
 	 */
-	if (p == (char *) 0 || text == (char *) 0)
+	if (p == (char *) 0 || text == (char *)0)
 		return FALSE;
 #ifdef OPTIMIZE_JUST_STAR
 	if (p[0] == '*' && p[1] == '\0')
 		return TRUE;
 #endif /* OPTIMIZE_JUST_STAR */
-
-	mesg[0] = '\0';
-
-	if (icase) {
-		txt = my_strdup(text);
-		str_lwr(txt);
-		str_lwr(p);
-		ret = (DoMatch(txt, p) == TRUE);
-		free (txt);
-	} else {
-		ret = (DoMatch(text, p) == TRUE);
-	}
-
-	return ret;
+	return DoMatch(text, p) == TRUE;
 }
